# Generated by Django 2.2.6 on 2020-02-25 09:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('review', '0013_review_author_anonym'),
    ]

    operations = [
        migrations.AddField(
            model_name='review',
            name='is_reviewd',
            field=models.BooleanField(default=True),
        ),
    ]
