# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-08-02 11:11
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import sorl.thumbnail.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='Screenshot',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('target_id', models.PositiveIntegerField()),
                ('_target', models.BooleanField(default=True)),
                ('src', sorl.thumbnail.fields.ImageField(height_field='width', upload_to='screenshots/', width_field='width')),
                ('width', models.IntegerField()),
                ('height', models.IntegerField()),
                ('description', models.TextField(blank=True, null=True)),
                ('_id', models.CharField(blank=True, max_length=24, null=True)),
                ('target_content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
            ],
            options={
                'verbose_name': 'Скриншот',
                'verbose_name_plural': 'Скриншоты',
            },
        ),
    ]
