# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-04-25 08:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qna', '0003_question__target'),
    ]

    operations = [
        migrations.AddField(
            model_name='question',
            name='slug',
            field=models.CharField(blank=True, max_length=200, null=True, unique=True),
        ),
    ]
