# Generated by Django 2.2.6 on 2020-02-25 13:43

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('review', '0015_auto_20200225_1301'),
    ]

    operations = [
        migrations.AlterField(
            model_name='review',
            name='author_anonym',
            field=models.CharField(default='Аноним', max_length=30, validators=[django.core.validators.MaxLengthValidator(30)]),
        ),
        migrations.AlterField(
            model_name='review',
            name='is_reviewd',
            field=models.BooleanField(default=False),
        ),
    ]
