# Generated by Django 2.2.6 on 2020-02-25 09:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('review', '0012_auto_20200225_0905'),
    ]

    operations = [
        migrations.AddField(
            model_name='review',
            name='author_anonym',
            field=models.CharField(blank=True, default='Аноним', max_length=100, null=True),
        ),
    ]
