# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-04-13 05:17
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('review', '0002_auto_20160412_1603'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='review',
            unique_together=set([('author', 'target_content_type', 'target_id')]),
        ),
    ]
