# Generated by Django 2.2.6 on 2019-11-01 11:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('review', '0010_remove_review__id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='review',
            name='_target',
            field=models.BooleanField(blank=True, default=True),
        ),
        migrations.AlterField(
            model_name='reviewstats',
            name='_target',
            field=models.BooleanField(blank=True, default=True),
        ),
    ]
